@@ -22,32 +22,27 @@ Copyright (c) 2016-2020, EPFL/Blue Brain Project
 # pylint:disable=W0612, W0201
 import json
 
-import nose.tools as nt
-from nose.plugins.attrib import attr
+
+import pytest
 
 from bluepyopt import ephys
 from bluepyopt.ephys.serializer import instantiator
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_location_init():
     """ephys.locations: test if Location works"""
 
     loc = ephys.locations.Location('test')
-    nt.assert_is_instance(loc, ephys.locations.Location)
-    nt.assert_equal(loc.name, 'test')
+    assert isinstance(loc, ephys.locations.Location)
+    assert loc.name == 'test'
 
 
-@attr('unit')
+@pytest.mark.unit
 class TestNrnSectionCompLocation(object):
 
     """Test class for NrnSectionCompLocation"""
 
-    def __init__(self):
-        """Constructor"""
-        self.loc = None
-        self.sim = None
-
     def setup(self):
         """Setup"""
         self.loc = ephys.locations.NrnSectionCompLocation(
@@ -58,7 +53,7 @@ class TestNrnSectionCompLocation(object):
             name='test',
             sec_name='dend[1]',
             comp_x=0.5)
-        nt.assert_equal(self.loc.name, 'test')
+        assert self.loc.name == 'test'
         self.sim = ephys.simulators.NrnSimulator()
 
     def test_instantiate(self):
@@ -78,22 +73,17 @@ class TestNrnSectionCompLocation(object):
         cell.dend = [dend1, dend2]
 
         soma_comp = self.loc.instantiate(sim=self.sim, icell=cell)
-        nt.assert_equal(soma_comp, soma(0.5))
+        assert soma_comp == soma(0.5)
 
         dend_comp = self.loc_dend.instantiate(sim=self.sim, icell=cell)
-        nt.assert_equal(dend_comp, dend2(0.5))
+        assert dend_comp == dend2(0.5)
 
 
-@attr('unit')
+@pytest.mark.unit
 class TestNrnSeclistCompLocation(object):
 
     """Test class for NrnSectionCompLocation"""
 
-    def __init__(self):
-        """Constructor"""
-        self.loc = None
-        self.sim = None
-
     def setup(self):
         """Setup"""
         self.loc = ephys.locations.NrnSeclistCompLocation(
@@ -106,7 +96,7 @@ class TestNrnSeclistCompLocation(object):
             seclist_name='basal',
             sec_index=1,
             comp_x=0.5)
-        nt.assert_equal(self.loc.name, 'test')
+        assert self.loc.name == 'test'
         self.sim = ephys.simulators.NrnSimulator()
 
     def test_instantiate(self):
@@ -129,32 +119,27 @@ class TestNrnSeclistCompLocation(object):
         cell.basal.append(dend2)
 
         soma_comp = self.loc.instantiate(sim=self.sim, icell=cell)
-        nt.assert_equal(soma_comp, soma(0.5))
+        assert soma_comp == soma(0.5)
 
         dend_comp = self.loc_dend.instantiate(sim=self.sim, icell=cell)
-        nt.assert_equal(dend_comp, dend2(0.5))
+        assert dend_comp == dend2(0.5)
 
         for _ in range(10000):
             soma_comp = self.loc.instantiate(sim=self.sim, icell=cell)
 
 
-@attr('unit')
+@pytest.mark.unit
 class TestNrnSomaDistanceCompLocation(object):
 
     """Test class for NrnSomaDistanceCompLocation"""
 
-    def __init__(self):
-        """Constructor"""
-        self.loc = None
-        self.sim = None
-
     def setup(self):
         """Setup"""
         self.loc = ephys.locations.NrnSomaDistanceCompLocation(
             'test',
             125,
             'testdend')
-        nt.assert_equal(self.loc.name, 'test')
+        assert self.loc.name == 'test'
         self.sim = ephys.simulators.NrnSimulator()
 
     def test_instantiate(self):
@@ -175,19 +160,19 @@ class TestNrnSomaDistanceCompLocation(object):
         cell.testdend.append(sec=dend1)
         cell.testdend.append(sec=dend2)
 
-        nt.assert_raises(ephys.locations.EPhysLocInstantiateException,
-                         self.loc.instantiate,
-                         sim=self.sim,
-                         icell=cell)
+        pytest.raises(ephys.locations.EPhysLocInstantiateException,
+                      self.loc.instantiate,
+                      sim=self.sim,
+                      icell=cell)
 
         dend1.connect(soma(0.5), 0.0)
         dend2.connect(dend1(1.0), 0.0)
 
         comp = self.loc.instantiate(sim=self.sim, icell=cell)
-        nt.assert_equal(comp, dend2(0.5))
+        assert comp == dend2(0.5)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_serialize():
     """ephys.locations: Test serialize functionality"""
     from bluepyopt.ephys.locations import (
@@ -209,8 +194,8 @@ def test_serialize():
 
     for loc in locations:
         serialized = loc.to_dict()
-        nt.ok_(isinstance(json.dumps(serialized), str))
+        assert isinstance(json.dumps(serialized), str)
         deserialized = instantiator(serialized)
-        nt.ok_(isinstance(deserialized, loc.__class__))
-        nt.eq_(deserialized.seclist_name, seclist_name)
-        nt.eq_(deserialized.name, loc.__class__.__name__)
+        assert isinstance(deserialized, loc.__class__)
+        assert deserialized.seclist_name == seclist_name
+        assert deserialized.name == loc.__class__.__name__
